//
//  FrameReader.h
//  ScreenMimic
//
//  Created by Lee Falin on 4/19/07.
//  Copyright 2007 __MyCompanyName__. All rights reserved.
//

#import <Cocoa/Cocoa.h>
#import "MP3Wrapper.h"

@interface FrameReader : NSObject 
{
	int currentFrame;
	int currentSequence;
	float frameRate;
	BOOL includeAudio;
	BOOL loopAudio;
	BOOL useAlternateAudioFile;
	BOOL useTransitions;
	
	int totalSequences;
	int totalFrames;
	int totalMP3Frames;
	NSString *pageFolderPath;
	NSImage *videoFrame;
	NSImage *backupImage;
	
	NSDictionary *videoRecordingData;
	NSDictionary *audioRecordingData;
	NSDictionary *recordingOptions;
	
	MP3Wrapper *mp3Wrapper;
	int mp3SamplesPerFrame;
	float idealAudioFrames;
	float idealAudioSamples;
	int currentIdealSamples;
	int realAudioSamples;
	int numberOfAudioFrames;
	int audioFramePointer;
	float samplingRate;

	signed short currentAudioFrameSeekSamples;
	int currentAudioFrameSize;
	NSMutableData *currentAudioFrameData;
	int blankFrameSize;
}

-(id)initWithRecordingOptions:(NSDictionary*)options andPageFolderPath:(NSString*)path containsTransitions:(BOOL)containsTransitions;

#pragma mark VIDEO FRAMES
-(NSDictionary *)videoRecordingData;
-(void)setVideoRecordingData:(NSDictionary *)value;
-(NSImage*)videoFrame;

#pragma mark AUDIO FRAMES
-(NSDictionary *)audioRecordingData;
-(void)setAudioRecordingData:(NSDictionary *)value;
-(BOOL)loadAudioSequence;
-(void)resetAudioCounters;
-(BOOL)includeAudio;
-(BOOL)useAlternateAudioFile;
-(void)setIncludeAudio:(BOOL)value;
-(int)samplingRate;
-(float)totalAudioSamples;
-(int)currentAudioFrameSize;
-(signed short)currentAudioFrameSeekSamples;
-(unsigned short)currentAudioFrameSampleCount;
-(NSData*)currentAudioFrameData;
-(NSData*)blankAudioFrame;
-(int)blankFrameSize;
-(void)setNextAudioFrame;


#pragma mark FRAME/SEQUENCE NAVIGATION
-(int)totalFrames;
-(int)totalSequences;
-(BOOL)nextSequence;
-(void)stepVideoForward;
-(void)stepAudioForward;
-(void)reset;



@end
